@@ -46,35 +46,35 @@ class AutoTraderBot():
     
     '''
     
-    def __init__(self, instrument, strategy_config, broker, autotrader_attributes):
+    def __init__(self, instrument, strategy_config, broker, data_dict, autotrader_instance):
         '''
         AutoTrader Bot initialisation. 
         '''
 
         # Inherit user options from autotrader
-        self.home_dir           = autotrader_attributes.home_dir
-        self.scan_mode          = autotrader_attributes.scan_mode
-        self.scan_index         = autotrader_attributes.scan_index
+        self.home_dir           = autotrader_instance.home_dir
+        self.scan_mode          = autotrader_instance.scan_mode
+        self.scan_index         = autotrader_instance.scan_index
         self.scan_results       = {}
-        self.broker_utils       = autotrader_attributes.broker_utils
-        self.email_params       = autotrader_attributes.email_params
-        self.notify             = autotrader_attributes.notify
-        self.verbosity          = autotrader_attributes.verbosity
-        self.order_summary_fp   = autotrader_attributes.order_summary_fp
-        self.backtest_mode      = autotrader_attributes.backtest_mode
-        self.data_start         = autotrader_attributes.data_start
-        self.data_end           = autotrader_attributes.data_end
-        self.base_currency      = autotrader_attributes.backtest_base_currency
-        self.environment        = autotrader_attributes.environment
-        self.feed               = autotrader_attributes.feed
-        self.data_file          = autotrader_attributes.data_file
-        self.MTF_data_files     = autotrader_attributes.MTF_data_files
-        self.optimise_mode      = autotrader_attributes.optimise_mode
-        self.check_data_alignment = autotrader_attributes.check_data_alignment
-        self.allow_dancing_bears = autotrader_attributes.allow_dancing_bears
-        self.use_stream         = autotrader_attributes.use_stream
-        self.stream_config      = autotrader_attributes.stream_config
-        self.MTF_initialisation = autotrader_attributes.MTF_initialisation
+        self.broker_utils       = autotrader_instance.broker_utils
+        self.email_params       = autotrader_instance.email_params
+        self.notify             = autotrader_instance.notify
+        self.verbosity          = autotrader_instance.verbosity
+        self.order_summary_fp   = autotrader_instance.order_summary_fp
+        self.backtest_mode      = autotrader_instance.backtest_mode
+        self.data_start         = autotrader_instance.data_start
+        self.data_end           = autotrader_instance.data_end
+        self.base_currency      = autotrader_instance.backtest_base_currency
+        self.environment        = autotrader_instance.environment
+        self.feed               = autotrader_instance.feed
+        self.data_file          = autotrader_instance.data_file
+        self.MTF_data_files     = autotrader_instance.MTF_data_files
+        self.optimise_mode      = autotrader_instance.optimise_mode
+        self.check_data_alignment = autotrader_instance.check_data_alignment
+        self.allow_dancing_bears = autotrader_instance.allow_dancing_bears
+        self.use_stream         = autotrader_instance.use_stream
+        self.stream_config      = autotrader_instance.stream_config
+        self.MTF_initialisation = autotrader_instance.MTF_initialisation
         
         # Assign local attributes
         self.instrument         = instrument
@@ -87,10 +87,10 @@ class AutoTraderBot():
         sizing                  = strategy_config["SIZING"] if 'SIZING' in strategy_config else 0
         params                  = strategy_config["PARAMETERS"]
         strategy_params                 = params
-        strategy_params['granularity']  = interval
-        strategy_params['risk_pc']      = risk_pc
-        strategy_params['sizing']       = sizing
-        strategy_params['period']       = period
+        strategy_params['granularity']  = strategy_params['granularity'] if 'granularity' in strategy_params else interval
+        strategy_params['risk_pc']      = strategy_params['risk_pc'] if 'risk_pc' in strategy_params else risk_pc
+        strategy_params['sizing']       = strategy_params['sizing'] if 'sizing' in strategy_params else sizing
+        strategy_params['period']       = strategy_params['period'] if 'period' in strategy_params else period
         self.strategy_params            = strategy_params
         
         # Import Strategy
@@ -142,6 +142,18 @@ class AutoTraderBot():
             self.MTF_data = None
         
         # Data retrieval
+        if data_dict is not None:
+            # Local data files provided
+            self.abs_data_filepath = True
+            if type(data_dict) == str:
+                # Single timeframe data file provided
+                self.data_file = data_dict
+            else:
+                # MTF data provided
+                self.MTF_data_files = data_dict
+        else:
+            self.abs_data_filepath = False
+        
         self.get_data = autodata.GetData(broker_config, self.allow_dancing_bears)
         data, quote_data, MTF_data = self._retrieve_data(instrument, self.feed)
         
@@ -247,6 +259,7 @@ class AutoTraderBot():
         interval    = self.strategy_params['granularity']
         period      = self.strategy_params['period']
         price_data_path = os.path.join(self.home_dir, 'price_data')
+        # TODO - assign price_data_path attribute 
         
         if self.backtest_mode is True:
             ' ~~~~~~~~~~~~~~~~~~~ Running in backtest mode ~~~~~~~~~~~~~~~~~~ '
@@ -258,8 +271,7 @@ class AutoTraderBot():
             if self.data_file is not None:
                 # Read local data file
                 custom_data_file        = self.data_file
-                custom_data_filepath    = os.path.join(price_data_path,
-                                                       custom_data_file)
+                custom_data_filepath    = os.path.join(price_data_path, custom_data_file) if not self.abs_data_filepath else custom_data_file
                 if int(self.verbosity) > 1:
                     print("Using data file specified ({}).".format(custom_data_file))
                 data            = pd.read_csv(custom_data_filepath, 
@@ -277,8 +289,8 @@ class AutoTraderBot():
                 MTF_data = {}
                 for granularity in MTF_data_files:
                     # Extract data 
-                    custom_data_filepath = os.path.join(price_data_path,
-                                                        MTF_data_files[granularity])
+                    custom_data_file = MTF_data_files[granularity]
+                    custom_data_filepath = os.path.join(price_data_path, custom_data_file) if not self.abs_data_filepath else custom_data_file
                     if int(self.verbosity) > 1:
                         print("Using data file specified ({}).".format(MTF_data_files[granularity]))
                     data = pd.read_csv(custom_data_filepath, index_col = 0)
@@ -361,7 +373,8 @@ class AutoTraderBot():
                                                                             from_date,
                                                                             to_date)
                         
-                            data, quote_data    = self.broker_utils.check_dataframes(data, quote_data)
+                            data, quote_data = self.broker_utils.check_dataframes(data.drop_duplicates(), 
+                                                                                  quote_data.drop_duplicates())
                         
                         MTF_data[granularity] = data
                     
@@ -650,7 +663,7 @@ class AutoTraderBot():
         for order in signal_dict:
             order_signal_dict = signal_dict[order].copy()
             
-            if order_signal_dict["direction"] != 0:
+            if order_signal_dict["direction"] != 0 or order_signal_dict["order_type"] == 'modify':
                 self._process_signal(order_signal_dict, i, self.data, 
                                     self.quote_data, self.instrument)
         
@@ -778,16 +791,24 @@ class AutoTraderBot():
         # Calculate exit levels
         pip_value   = self.broker_utils.get_pip_ratio(instrument)
         stop_distance = order_signal_dict['stop_distance'] if 'stop_distance' in order_signal_dict else None
-        stop_type = order_signal_dict['stop_type'] if 'stop_type' in order_signal_dict else None
         
         # Calculate stop loss price
         if 'stop_loss' not in order_signal_dict and \
             'stop_distance' in order_signal_dict and \
             order_signal_dict['stop_distance'] is not None:
+            # Stop loss provided as pip distance, convert to price
             stop_price = working_price - np.sign(signal)*stop_distance*pip_value
         else:
+            # Stop loss provided as price
             stop_price = order_signal_dict['stop_loss'] if 'stop_loss' in order_signal_dict else None
         
+        # Set stop type
+        if stop_price is not None:
+            stop_type = order_signal_dict['stop_type'] if 'stop_type' in order_signal_dict else 'limit'
+        else:
+            # No stop loss specified 
+            stop_type = None
+            
         # Calculate take profit price
         if 'take_profit' not in order_signal_dict and \
             'take_distance' in order_signal_dict and \
